==> Rfast_2.0.8.tar.gz: Rfast/R/onAttach.R <==

#[export special]
.onAttach <- function(lib, pkg) {
	version <- read.dcf(file.path(lib, pkg, "DESCRIPTION"),"Version")
	packageStartupMessage(paste("\nRfast: ",version))
	msg <-  paste(
			r"( ___ __ __ __ __    __ __ __ __ __ _             _               __ __ __ __ __     __ __ __ __ __ __   )",
			r"(|  __ __ __ __  |  |  __ __ __ __ _/            / \             |  __ __ __ __ /   /__ __ _   _ __ __\  )",
			r"(| |           | |  | |                         / _ \            | |                        / /          )",
			r"(| |           | |  | |                        / / \ \           | |                       / /          )",
			r"(| |           | |  | |                       / /   \ \          | |                      / /          )",
			r"(| |__ __ __ __| |  | |__ __ __ __           / /     \ \         | |__ __ __ __ _        / /__/\          )",
			r"(|    __ __ __ __|  |  __ __ __ __|         / /__ _ __\ \        |_ __ __ __ _   |      / ___  /           )",
			r"(|   \              | |                    / _ _ _ _ _ _ \                     | |      \/  / /       )",
			r"(| |\ \             | |                   / /           \ \                    | |         / /          )",
			r"(| | \ \            | |                  / /             \ \                   | |        / /          )",
			r"(| |  \ \           | |                 / /               \ \                  | |       / /          )",
			r"(| |   \ \__ __ _   | |                / /                 \ \     _ __ __ __ _| |      / /          )",
			r"(|_|    \__ __ __\  |_|               /_/                   \_\   /_ __ __ __ ___|      \/             team)"
	,sep="\n")
	packageStartupMessage(msg)
}

==> Rfast_2.0.9.tar.gz: Rfast/R/onAttach.R <==

#[export special]
.onAttach <- function(lib, pkg) {
	version <- read.dcf(file.path(lib, pkg, "DESCRIPTION"),"Version")
	packageStartupMessage(paste("\n",pkg["name"],": ",version,sep = ""))
	msg <-  paste(
			r"( ___ __ __ __ __    __ __ __ __ __ _             _               __ __ __ __ __     __ __ __ __ __ __   )",
			r"(|  __ __ __ __  |  |  __ __ __ __ _/            / \             |  __ __ __ __ /   /__ __ _   _ __ __\  )",
			r"(| |           | |  | |                         / _ \            | |                        / /          )",
			r"(| |           | |  | |                        / / \ \           | |                       / /          )",
			r"(| |           | |  | |                       / /   \ \          | |                      / /          )",
			r"(| |__ __ __ __| |  | |__ __ __ __           / /     \ \         | |__ __ __ __ _        / /__/\          )",
			r"(|    __ __ __ __|  |  __ __ __ __|         / /__ _ __\ \        |_ __ __ __ _   |      / ___  /           )",
			r"(|   \              | |                    / _ _ _ _ _ _ \                     | |      \/  / /       )",
			r"(| |\ \             | |                   / /           \ \                    | |         / /          )",
			r"(| | \ \            | |                  / /             \ \                   | |        / /          )",
			r"(| |  \ \           | |                 / /               \ \                  | |       / /          )",
			r"(| |   \ \__ __ _   | |                / /                 \ \     _ __ __ __ _| |      / /          )",
			r"(|_|    \__ __ __\  |_|               /_/                   \_\   /_ __ __ __ ___|      \/             team)"
	,sep="\n")
	packageStartupMessage(msg)
}
